<script setup>

import * as Plot from "@observablehq/plot";
import * as d3 from "d3";
import {ref} from "vue";
import crimea from "../data/crimea.ts";

const marker = ref("circle");

</script>

# Markers

A **marker** defines a graphic drawn on vertices of a [line](../marks/line.md) or [link](../marks/link.md) mark.

<p>
  <label class="label-input">
    Marker:
    <select v-model="marker">
      <option>none</option>
      <option>arrow</option>
      <option>arrow-reverse</option>
      <option>dot</option>
      <option>circle</option>
      <option>circle-stroke</option>
    </select>
  </label>
</p>

:::plot https://observablehq.com/d/cfc5b4e46aa18b57?intent=fork
```js-vue
Plot.plot({
  marks: [
    Plot.ruleY([0]),
    Plot.lineY(crimea, {x: "date", y: "deaths", stroke: "cause", marker: "{{marker}}"})
  ]
})
```
:::

The supported marker options are:

* **markerStart** - the marker for the starting point of a line segment
* **markerMid** - the marker for any intermediate point of a line segment
* **markerEnd** - the marker for the end point of a line segment
* **marker** - shorthand for setting the marker on all points

The following named markers are supported:

* *none* (default) - no marker
* *arrow* - an arrowhead with *auto* orientation
* *arrow-reverse* - an arrowhead with *auto-start-reverse* orientation
* *dot* - a filled *circle* without a stroke and 2.5px radius
* *circle*, equivalent to *circle-fill* - a filled circle with a white stroke and 3px radius
* *circle-stroke* - a hollow circle with a colored stroke and a white fill and 3px radius

If **marker** is true, it defaults to *circle*. If **marker** is a function, it will be called with a given *color* and must return an [SVG marker element](https://developer.mozilla.org/en-US/docs/Web/SVG/Element/marker).

The primary color of a marker is inherited from the *stroke* of the associated mark. The *arrow* marker is [automatically oriented](https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/orient) such that it points in the tangential direction of the path at the position the marker is placed. The *circle* markers are centered around the given vertex.

For lines whose [curve](./curves.md) is not *linear*, markers are not necessarily drawn at the data positions given by **x** and **y**; marker placement is determined by the (possibly Bézier) path segments generated by the curve. To ensure that symbols are drawn at a given **x** and **y** position, consider using a [dot mark](../marks/dot.md) instead.
